# MADAS - the **MA**terials **DA**ta **S**imilarity framework

*MADAS* is a Python framework for calculating fingerprints and similarities from materials science data.

## Documentation

The documentation can be found here:

[MADAS documentation at readthedocs](https://madas.readthedocs.io)

## Install

*MADAS* can be installed via pip:

```bash
pip install madas
```

For installation from source, please execute:

```bash
git clone --recurse-submodules https://github.com/kubanmar/madas.git
cd madas
pip install .
```

## How to cite

If you use `MADAS`, please cite our paper:

Martin Kuban, Santiago Rigamonti, and Claudia Draxl:  
MADAS: a Python framework for assessing similarity in materials-science data  
*Digital Discovery* **3**, (2024), 2448-2457